==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Stai per cancellare tutte le adesioni a questa petizione. Sei sicuro di voler continuare?',
	'aucune_signature' => 'Nessuna firma',

	// B
	'bouton_checkbox_envoi_message' => 'possibilità di inviare un messaggio',
	'bouton_checkbox_indiquer_site' => 'devi inserire il nome di un sito web',
	'bouton_checkbox_signature_unique_email' => 'solo un’adesione per email',
	'bouton_checkbox_signature_unique_site' => 'solo una adesione per sito web',

	// F
	'filtre' => 'Filtro:',
	'form_pet_adresse_site' => 'Indirizzo del sito',
	'form_pet_aucune_signature' => 'A questo codice non corrisponde nessuna desione ...',
	'form_pet_confirmation' => 'Conferma l’adesione:',
	'form_pet_deja_signe' => 'Hai già firmato questo testo.',
	'form_pet_envoi_mail_confirmation' => 'Ti è stato appena inviato un messaggio di posta elettronica all’indirizzo @email@. Dovrai visitare l’indirizzo web che appare nel messaggio per confermare la tua adesione.',
	'form_pet_mail_confirmation' => 'Salve,

Hai richiesto di aderire alla petizione:
@titre@.

Hai fornito le seguenti informazioni:
    Nome: @nom_email@
    Sito: @nom_site@ - @url_site@
    @message@

IMPORTANTE...

Per confermare la tua adesione è sufficiente visitare l’indirizzo web qui sotto (se non lo fai, la tua domanda sarà respinta):

    @url@


Grazie per la partecipazione',
	'form_pet_message_commentaire' => 'Un messaggio, un commento?',
	'form_pet_nom_site2' => 'Nome del tuo sito web',
	'form_pet_probleme_liens' => 'Per favore, riprenda il suo messaggio ed elimini i link ipertestuali.',
	'form_pet_probleme_technique' => 'Le adesioni sono temporaneamente sospese per il verificarsi di problemi tecnici.',
	'form_pet_signature_validee' => 'La tua adesione è stata confermata. Grazie!',
	'form_pet_site_deja_enregistre' => 'Questo sito è già registrato',
	'form_pet_url_invalide' => 'L’URL indicato non risulta valido.',
	'form_pet_votre_email' => 'Il tuo indirizzo email',
	'form_pet_votre_nom' => 'Il tuo nome',
	'form_pet_votre_site' => 'Se hai un sito Web, puoi segnalarlo qui sotto',

	// I
	'icone_relancer_signataire' => 'Contatta il firmatario di nuovo',
	'icone_relancer_signataires' => 'Contatta di nuovo i firmatari',
	'icone_suivi_petitions' => 'Segui/gestisci le petizioni',
	'icone_supprimer_signature' => 'Cancella questa adesione',
	'icone_supprimer_signatures' => 'Cancella le adesioni',
	'icone_valider_signature' => 'Conferma l’adesione',
	'icone_valider_signatures' => 'Conferma le adesioni',
	'info_adresse_email' => 'INDIRIZZO EMAIL:',
	'info_fonctionnement_petition' => 'Come funzionano le petizioni:',
	'info_signature_supprimee' => 'Firma eliminata',
	'info_signature_supprimee_erreur' => 'Errore: questo codice di eliminazione non corrisponde a nessuna firma',
	'info_site_web' => 'SITO WEB:',
	'info_texte_message' => 'Testo del tuo messaggio:',

	// L
	'lien_reponse_article' => 'Risposta all’articolo',

	// N
	'nombre_signatures' => '@nb@ adesioni',

	// S
	'sans_nom' => 'Anonimo',
	'signatures_article' => 'Firmatari dell’articolo:',
	'signatures_aucune' => 'Nessuna',
	'signatures_meme_auteur' => 'Adesioni dello stesso autore',
	'signatures_meme_site' => 'Adesioni con lo stesso sito web',
	'signatures_poubelle' => 'Cancellata',
	'signatures_prop' => 'Attendere',
	'signatures_publie' => 'Confermata',
	'signatures_recherche_label' => 'Ricercare per adesione:',
	'signatures_selection' => 'Seleziona la firma:',
	'signatures_toutes' => 'Tutte',
	'statut_poubelle' => 'Cancellata',
	'statut_prop' => 'Aspettando la validazione',
	'statut_publie' => 'Confermata',

	// T
	'texte_descriptif_petition' => 'Descrizione della petizione',
	'titre_page_controle_petition' => 'Tracciatura della petizione',
	'titre_petition' => 'Petizione',
	'titre_petitions' => 'Petizioni',
	'titre_selection_action' => 'Selezione',
	'titre_signatures_attente' => 'Adesioni in attesa di valisazione',
	'titre_signatures_publie' => 'Conferma adesioni',
	'titre_suivi_petition' => 'Tracciatura delle petizioni',
	'tout_voir' => 'Mostra tutte le adesioni',

	// U
	'une_signature' => '1 adesione',

	// V
	'voir_signatures_objet' => 'Mostra le adesioni'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Stai per cancellare tutte le adesioni a questa petizione. Sei sicuro di voler continuare?',
	'aucune_signature' => 'Nessuna firma',

	// B
	'bouton_checkbox_envoi_message' => 'possibilità di inviare un messaggio',
	'bouton_checkbox_indiquer_site' => 'devi inserire il nome di un sito web',
	'bouton_checkbox_signature_unique_email' => 'solo un’adesione per email',
	'bouton_checkbox_signature_unique_site' => 'solo una adesione per sito web',
	'bouton_radio_activer_petition' => 'Attiva la petizione',
	'bouton_radio_pas_petition' => 'Nessuna petizione',
	'bouton_radio_petition_activee' => 'Petizione attivata',
	'bouton_radio_supprimer_petition' => 'Elimina la petizione',

	// F
	'filtre' => 'Filtro:',
	'form_pet_adresse_site' => 'Indirizzo del sito',
	'form_pet_aucune_signature' => 'A questo codice non corrisponde nessuna desione ...',
	'form_pet_confirmation' => 'Conferma l’adesione:',
	'form_pet_deja_signe' => 'Hai già firmato questo testo.',
	'form_pet_envoi_mail_confirmation' => 'Ti è stato appena inviato un messaggio di posta elettronica all’indirizzo @email@. Dovrai visitare l’indirizzo web che appare nel messaggio per confermare la tua adesione.',
	'form_pet_mail_confirmation' => 'Salve,

Hai richiesto di aderire alla petizione:
@titre@.

Hai fornito le seguenti informazioni:
    Nome: @nom_email@
    Sito: @nom_site@ - @url_site@
    @message@

IMPORTANTE...

Per confermare la tua adesione è sufficiente visitare l’indirizzo web qui sotto (se non lo fai, la tua domanda sarà respinta):

    @url@


Grazie per la partecipazione',
	'form_pet_message_commentaire' => 'Un messaggio, un commento?',
	'form_pet_nom_site2' => 'Nome del tuo sito web',
	'form_pet_probleme_liens' => 'Per favore, riprenda il suo messaggio ed elimini i link ipertestuali.',
	'form_pet_probleme_technique' => 'Le adesioni sono temporaneamente sospese per il verificarsi di problemi tecnici.',
	'form_pet_signature_validee' => 'La tua adesione è stata confermata. Grazie!',
	'form_pet_site_deja_enregistre' => 'Questo sito è già registrato',
	'form_pet_url_invalide' => 'L’URL indicato non risulta valido.',
	'form_pet_votre_email' => 'Il tuo indirizzo email',
	'form_pet_votre_nom' => 'Il tuo nome',
	'form_pet_votre_site' => 'Se hai un sito Web, puoi segnalarlo qui sotto',

	// I
	'icone_relancer_signataire' => 'Contatta il firmatario di nuovo',
	'icone_relancer_signataires' => 'Contatta di nuovo i firmatari',
	'icone_suivi_petitions' => 'Segui/gestisci le petizioni',
	'icone_supprimer_signature' => 'Cancella questa adesione',
	'icone_supprimer_signatures' => 'Cancella le adesioni',
	'icone_valider_signature' => 'Conferma l’adesione',
	'icone_valider_signatures' => 'Conferma le adesioni',
	'info_adresse_email' => 'INDIRIZZO EMAIL:',
	'info_fonctionnement_petition' => 'Come funzionano le petizioni:',
	'info_signature_supprimee' => 'Firma eliminata',
	'info_signature_supprimee_erreur' => 'Errore: questo codice di eliminazione non corrisponde a nessuna firma',
	'info_site_web' => 'SITO WEB:',
	'info_texte_message' => 'Testo del tuo messaggio:',

	// L
	'lien_reponse_article' => 'Risposta all’articolo',

	// N
	'nombre_signatures' => '@nb@ adesioni',

	// S
	'sans_nom' => 'Anonimo',
	'signatures_article' => 'Firmatari dell’articolo:',
	'signatures_aucune' => 'Nessuna',
	'signatures_meme_auteur' => 'Adesioni dello stesso autore',
	'signatures_meme_site' => 'Adesioni con lo stesso sito web',
	'signatures_poubelle' => 'Cancellata',
	'signatures_prop' => 'Attendere',
	'signatures_publie' => 'Confermata',
	'signatures_recherche_label' => 'Ricercare per adesione:',
	'signatures_selection' => 'Seleziona la firma:',
	'signatures_toutes' => 'Tutte',
	'statut_poubelle' => 'Cancellata',
	'statut_prop' => 'Aspettando la validazione',
	'statut_publie' => 'Confermata',

	// T
	'texte_descriptif_petition' => 'Descrizione della petizione',
	'titre_page_controle_petition' => 'Tracciatura della petizione',
	'titre_petition' => 'Petizione',
	'titre_petitions' => 'Petizioni',
	'titre_selection_action' => 'Selezione',
	'titre_signatures_attente' => 'Adesioni in attesa di valisazione',
	'titre_signatures_publie' => 'Conferma adesioni',
	'titre_suivi_petition' => 'Tracciatura delle petizioni',
	'tout_voir' => 'Mostra tutte le adesioni',

	// U
	'une_signature' => '1 adesione',

	// V
	'voir_signatures_objet' => 'Mostra le adesioni'
);

?>
